@@ -2,12 +2,12 @@ import RPi.GPIO as GPIO
 import os
 import copy
 import time
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, timezone
 from pathlib import Path
 from baseutils_phornee import ManagedClass
 from baseutils_phornee import Logger
-from influxdb_client import InfluxDBClient, Point, WritePrecision
-from influxdb_client.client.write_api import SYNCHRONOUS
+from influxdb import InfluxDBClient
+
 import json
 
 class Waterflow(ManagedClass):
@@ -17,11 +17,21 @@ class Waterflow(ManagedClass):
 
         self.logger = Logger({'modulename': self.getClassName(), 'logpath': 'log'})
 
-        token = self.config['influxdbconn']['token']
-        self.org = self.config['influxdbconn']['org']
-        self.bucket = self.config['influxdbconn']['bucket']
+        try:
+            host = self.config['influxdbconn']['host']
+            user = self.config['influxdbconn']['user']
+            password = self.config['influxdbconn']['password']
+            bucket = self.config['influxdbconn']['bucket']
+        except Exception as e:
+            self.logger.warning('Error getting connection credentials to InfluxDB.')
+            pass
 
-        self.conn = InfluxDBClient(url=self.config['influxdbconn']['url'], token=token)
+        try:
+            self.conn = InfluxDBClient(host=host, username=user, password=password, database=bucket)
+        except Exception as e:
+            self.logger.warning('Connection to InfluxDB failed: %s.' % host)
+            self.conn = None
+            pass
 
     @classmethod
     def getClassName(cls):
@@ -32,7 +42,9 @@ class Waterflow(ManagedClass):
 
         # Convert the date from string to datetime object
         for program in self.config['programs']:
-            program['start_time'] = datetime.strptime(program['start_time'], '%H:%M:%S')
+            progtime = datetime.strptime(program['start_time'], '%H:%M:%S')
+            progtime = self._setTimezoneUTC(progtime)
+            program['start_time'] = progtime
 
         # Sort the programs by time
         self.config['programs'].sort(key=lambda prog: prog['start_time'])
@@ -40,7 +52,7 @@ class Waterflow(ManagedClass):
     def writeConfig(self, config):
         conf = copy.deepcopy(config)
 
-        #self.setCache(config)
+        self.setCache(config)
 
         # Convert the date back from datetime to string
         for program in conf['programs']:
@@ -48,6 +60,14 @@ class Waterflow(ManagedClass):
 
         super().writeConfig(conf)
 
+    def _setTimezoneUTC(self, date):
+        import pytz
+
+        return pytz.timezone('UTC').localize(date)
+
+    def _getNowUTC(self):
+        return datetime.now(timezone.utc)
+
     def _timeToStr(self, time_var):
         return time_var.strftime('%Y-%m-%d %H:%M:%S\n')
 
@@ -71,7 +91,8 @@ class Waterflow(ManagedClass):
         next_program_time = None
         program_number = -1
 
-        current_time = datetime.now().replace(microsecond=0)
+        #current_time = self._getNowUTC().replace(microsecond=0)
+        current_time = datetime.now()
 
         # Find if next program is today, considering the last program time executed
         for idx, program in enumerate(self.config['programs']):
@@ -107,8 +128,9 @@ class Waterflow(ManagedClass):
         try:
             with open(last_program_path, 'r') as file:
                 data = file.readlines()
-                last_program_time = datetime.strptime(data[0][:-1], '%Y-%m-%d %H:%M:%S')
+                last_program_time = datetime.strptime(data[0][:-1], '%Y-%m-%d %H:%M:%S', tzinfo=datetime.timezone.utc)
         except Exception as e:
+            #last_program_time = self._getNowUTC()
             last_program_time = datetime.now()
             with open(last_program_path, 'w') as file:
                 time_str = self._timeToStr(last_program_time)
@@ -147,12 +169,15 @@ class Waterflow(ManagedClass):
             self.logger.error(f"Could not release lock.")
 
     def isLoopingCorrectly(self):
+        return (datetime.utcnow() - self.getLastLoopTime()) < timedelta(minutes=10)
+
+    def getLastLoopTime(self):
         tokenpath = os.path.join(self.getHomevarPath(), 'token')
 
         modTimesinceEpoc = os.path.getmtime(tokenpath)
         modificationTime = datetime.utcfromtimestamp(modTimesinceEpoc)
 
-        return (datetime.utcnow() - modificationTime) < timedelta(minutes=10)
+        return modificationTime
 
     def force(self, type_force, value):
         config = self.getConfig()
@@ -200,15 +225,21 @@ class Waterflow(ManagedClass):
             time.sleep(5)  # Every X seconds
 
     def _emitActionMetric(self, action, forced):
-        write_api = self.conn.write_api(write_options=SYNCHRONOUS)
-
-        point = Point('piwaterflow') \
-            .tag('action', action) \
-            .tag('forced', forced) \
-            .field('fake', 0) \
-            .time(datetime.utcnow(), WritePrecision.NS)
-
-        write_api.write(self.bucket, self.org, point)
+        if self.conn:
+            json_body = [
+                {
+                    "measurement": "piwaterflow",
+                    "tags": {
+                        "action": action,
+                        "forced": forced
+                    },
+                    "time": datetime.utcnow(),
+                    "fields": {
+                        "fake": 0
+                    }
+                }
+            ]
+            self.conn.write_points(json_body)
 
     def _executeValve(self, valve):
         # ------------------------------------
@@ -288,6 +319,7 @@ class Waterflow(ManagedClass):
     def loop(self):
         if self.getLock():  # To ensure a single execution despite of cron overlapping
             try:
+                #current_time = self._getNowUTC()
                 current_time = datetime.now()
                 forced_info = self.getForcedInfo()
 
